@@ -45,7 +45,7 @@ Tags can be expanded via:
     is $$modules{"FP::Failure"}, 2; # number of times used.
     use FP::Equal 'is_equal';
     is_equal $unused_tags,
-             [':all', ':csv', ':dbi', ':fix', ':git', ':io', ':path', ':pxml', ':rare', ':trampoline', ':transparentlazy'];
+             [':all', ':ast', ':csv', ':dbi', ':fix', ':git', ':io', ':path', ':pxml', ':rare', ':trampoline', ':transparentlazy'];
 
 =head1 SEE ALSO
 
@@ -53,6 +53,8 @@ This is the list of supported import tags and the modules that they import:
 
 C<:all>: C<:dev>, C<:io>, C<:most>, C<:rare>
 
+C<:ast>: L<FP::AST::Perl>
+
 C<:autobox>: L<FP::autobox>
 
 C<:chars>: L<FP::Char>
@@ -132,7 +134,7 @@ package FunctionalPerl;
 
 use strict; use warnings; use warnings FATAL => 'uninitialized';
 
-our $VERSION= "0.72.22";
+our $VERSION= "0.72.23";
 
 
 # Export tag to modules and/or other tags; each module will be
@@ -166,6 +168,7 @@ our $export_desc=
                        :show :equal :failure)],
     ":git"=> [qw(FP::Git::Repository)],
     ":pxml"=> [qw(PXML::Util PXML::XHTML PXML::Serialize)],
+    ":ast"=> [qw(FP::AST::Perl)],
 
     ":numbers"=> [qw(FP::BigInt)],
     ":chars"=> [qw(FP::Char)],
